StateStore class abstract

Implementers
Available extensions

Constructors

StateStore()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String key) String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put(String key, String value) → void
remove(String key) → void
restoreHydrated<T>({required String storageKey, required T stateFromJson(Map<String, dynamic> json)}) → T?

Available on StateStore, provided by the HydratedStateHolderStateStore extension

storeForHydration<T>({required String storageKey, required T state, required Map<String, dynamic> stateToJson(T state)}) → void

Available on StateStore, provided by the HydratedStateHolderStateStore extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited